@@ -3,6 +3,9 @@ from typing import List
 from pykkn.dataset import Dataset
 from pykkn.instrument import Instrument
 from pykkn.storage import Storage
+from pykkn.dataset_image import Dataset_Image
+from pykkn.dataset_video import Dataset_Video
+
 
 
 class Pipeline(Storage):
@@ -67,7 +70,7 @@ class Pipeline(Storage):
         for item in list_obj:
             if isinstance(item, Instrument):
                 self.instruments.append(item)
-            elif isinstance(item, Dataset):
+            elif isinstance(item, Dataset) or isinstance(item, Dataset_Image) or isinstance(item, Dataset_Video):
                 self.data.append(item)
             else:
                 raise TypeError(
